==> zio-aws-rekognition_2.12-5.17.128.1-sources.jar: zio/aws/rekognition/model/Landmark.scala <==
package zio.aws.rekognition.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Landmark(
    `type`: Option[zio.aws.rekognition.model.LandmarkType] = None,
    x: Option[Float] = None,
    y: Option[Float] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.Landmark = {
    import Landmark.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.Landmark
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(x.map(value => value: java.lang.Float))(_.x)
      .optionallyWith(y.map(value => value: java.lang.Float))(_.y)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.Landmark.ReadOnly =
    zio.aws.rekognition.model.Landmark.wrap(buildAwsValue())
}
object Landmark {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.Landmark
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.Landmark =
      zio.aws.rekognition.model.Landmark(
        `type`.map(value => value),
        x.map(value => value),
        y.map(value => value)
      )
    def `type`: Option[zio.aws.rekognition.model.LandmarkType]
    def x: Option[Float]
    def y: Option[Float]
    def getType: ZIO[Any, AwsError, zio.aws.rekognition.model.LandmarkType] =
      AwsError.unwrapOptionField("type", `type`)
    def getX: ZIO[Any, AwsError, Float] = AwsError.unwrapOptionField("x", x)
    def getY: ZIO[Any, AwsError, Float] = AwsError.unwrapOptionField("y", y)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.Landmark
  ) extends zio.aws.rekognition.model.Landmark.ReadOnly {
    override val `type`: Option[zio.aws.rekognition.model.LandmarkType] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.rekognition.model.LandmarkType.wrap(value))
    override val x: Option[Float] =
      scala.Option(impl.x()).map(value => value: Float)
    override val y: Option[Float] =
      scala.Option(impl.y()).map(value => value: Float)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.Landmark
  ): zio.aws.rekognition.model.Landmark.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rekognition_2.12-5.19.7.5-sources.jar: zio/aws/rekognition/model/Landmark.scala <==
package zio.aws.rekognition.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Landmark(
    `type`: Optional[zio.aws.rekognition.model.LandmarkType] = Optional.Absent,
    x: Optional[Float] = Optional.Absent,
    y: Optional[Float] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.Landmark = {
    import Landmark.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.Landmark
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(x.map(value => value: java.lang.Float))(_.x)
      .optionallyWith(y.map(value => value: java.lang.Float))(_.y)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.Landmark.ReadOnly =
    zio.aws.rekognition.model.Landmark.wrap(buildAwsValue())
}
object Landmark {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.Landmark
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.Landmark =
      zio.aws.rekognition.model.Landmark(
        `type`.map(value => value),
        x.map(value => value),
        y.map(value => value)
      )
    def `type`: Optional[zio.aws.rekognition.model.LandmarkType]
    def x: Optional[Float]
    def y: Optional[Float]
    def getType: ZIO[Any, AwsError, zio.aws.rekognition.model.LandmarkType] =
      AwsError.unwrapOptionField("type", `type`)
    def getX: ZIO[Any, AwsError, Float] = AwsError.unwrapOptionField("x", x)
    def getY: ZIO[Any, AwsError, Float] = AwsError.unwrapOptionField("y", y)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.Landmark
  ) extends zio.aws.rekognition.model.Landmark.ReadOnly {
    override val `type`: Optional[zio.aws.rekognition.model.LandmarkType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.rekognition.model.LandmarkType.wrap(value))
    override val x: Optional[Float] = zio.aws.core.internal
      .optionalFromNullable(impl.x())
      .map(value => value: Float)
    override val y: Optional[Float] = zio.aws.core.internal
      .optionalFromNullable(impl.y())
      .map(value => value: Float)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.Landmark
  ): zio.aws.rekognition.model.Landmark.ReadOnly = new Wrapper(impl)
}
